<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/paquet-dump?lang_cible=eo
// ** ne pas modifier le fichier **

return [

	// D
	'dump_description' => 'Savkopio de la datumbazo en SQLite kaj restaŭro',
	'dump_slogan' => 'Savkopio kaj restaŭro de la datumbazo SPIP',
];
